(function () {
  'use strict';

  sc.appendDateRange = function (graphParameters) {
    var FORMAT = 'MMM DD YYYY';

    $('div#date-range strong')
      .empty()
      .append(graphParameters.startDate.format(FORMAT) + ' - ' + graphParameters.endDate.format(FORMAT));
  };

  sc.drawEmotionViz = function(graphParameters) {
    var GRAPH_DIV_ID = '#emotions';
    var GRAPH_TITLE = 'Positive and Negative Emotions*';
    var LEGEND = [['Positive', '#4682B4'], ['Negative', '#A52A2A'], ['Daily Average', 'green']];
    var LEGEND_DIV_ID = '#emotion-legend';
    var PIXEL_HEIGHT = 400;
    var Y_MAX = 10;
    var Y_MIN = -10;
    var YLABEL = 'Intensity';

    $('div#emotions, div#emotion-legend').empty();
    d3.select(GRAPH_DIV_ID)
      .datum(graphParameters.emotionsData)
        .call(columnChart(graphParameters.startDate, graphParameters.endDate, Y_MIN, Y_MAX, GRAPH_TITLE, YLABEL)
          .width(graphParameters.graphWidth)
          .height(PIXEL_HEIGHT)
          .x(function(date, i) {
            return moment(date.day, 'YYYY-MM-DD').startOf('day').toDate();
          })
          .drawLegend(LEGEND_DIV_ID, LEGEND, ['*Click each day for more information.']));
  };

  sc.drawMoodViz = function(graphParameters) {
    var GRAPH_DIV_ID = '#mood';
    var GRAPH_TITLE = 'Mood*';
    var LEGEND = [['Mood', '#4682B4'], ['Daily Average', 'green']];
    var LEGEND_DIV_ID = '#mood-legend';
    var PIXEL_HEIGHT = 300;
    var Y_MAX = 10;
    var Y_MIN = 0;
    var YLABEL = 'mood';

    $('div#mood, div#mood-legend').empty();
    d3.select(GRAPH_DIV_ID)
      .datum(graphParameters.moodData)
        .call(columnChart(graphParameters.startDate, graphParameters.endDate, Y_MIN, Y_MAX, GRAPH_TITLE, YLABEL)
          .width(graphParameters.graphWidth)
          .height(PIXEL_HEIGHT)
          .x(function(date, i) {
            return moment(date.day, 'YYYY-MM-DD').startOf('day').toDate();
          })
          .y(function(date, i) {
            return date.intensity;
          })
          .drawLegend(LEGEND_DIV_ID, LEGEND, ['*Click each day for more information.']));
  };

  sc.drawPHQViz = function(graphParameters) {
    var GRAPH_DIV_ID = '#phq';
    var GRAPH_TITLE = "PHQ9";
    var PIXEL_HEIGHT = 300;
    var Y_MAX = 27;
    var Y_MIN = 0;
    var YLABEL = 'Score';

    $(GRAPH_DIV_ID).empty();
    d3.select(GRAPH_DIV_ID)
      .datum(graphParameters.phqData)
        .call(columnChart(graphParameters.startDate, graphParameters.endDate, Y_MIN, Y_MAX, GRAPH_TITLE, YLABEL)
          .width(graphParameters.graphWidth)
          .height(PIXEL_HEIGHT)
          .y(function(date, i) {
            return date.intensity;
          }));
  };

  sc.drawGraphs = function(graphParameters) {
    sc.drawPHQViz(graphParameters);
    sc.drawMoodViz(graphParameters);
    sc.drawEmotionViz(graphParameters);
    sc.appendDateRange(graphParameters);
  };
})();
