# frozen_string_literal: true
require_dependency "think_feel_do_engine/application_controller"

module ThinkFeelDoEngine
  module Coach
    # Present Participant Activities Visualization to the Coach.
    class ParticipantActivitiesVisualizationsController < ApplicationController
      before_action :authenticate_user!
      rescue_from ActiveRecord::RecordNotFound, with: :record_not_found

      RenderOptions = Struct.new(
        :view_context, :app_context, :position, :participant
      )

      def show
        @participant = Participant.find(params[:participant_id])
        @group = @participant.groups.find(params[:group_id])
        provider = ContentProviders::YourActivitiesProvider.new
        options = RenderOptions.new(
          self,
          @participant.navigation_status,
          @participant.navigation_status.content_position,
          @participant
        )
        provider.render_current(options)
      end

      def record_not_found
        redirect_to main_app.root_path,
                    alert: "The activities visualization you were "\
                    "looking does not exist."
      end
    end
  end
end
