# frozen_string_literal: true
require_dependency "think_feel_do_engine/application_controller"

module ThinkFeelDoEngine
  module Manage
    # Users can view groups to CRUD and assign slideshows
    class GroupsController < ApplicationController
      before_action :authenticate_user!, :set_arm
      rescue_from ActiveRecord::RecordNotFound, with: :record_not_found

      def index
        authorize! :index, Group
        @groups = Group.all
      end

      def edit_tasks
        @group = @arm.groups
                     .includes(tasks: { bit_core_content_module: :tool })
                     .find(params[:id])
        authorize! :update, @group
        @task = current_user.tasks.build
        @content_modules = BitCore::ContentModule
                           .where(bit_core_tool_id: @arm.bit_core_tool_ids)
                           .includes(:tool)
      end

      private

      def set_arm
        @arm = Arm.find(params[:arm_id])
      end

      def record_not_found
        redirect_to main_app.root_path,
                    alert: "The group you are looking for no longer exists."
      end
    end
  end
end
