# frozen_string_literal: true
module GroupMetrics
  # Tabulate count of Activities (within a study week) for a Group.
  class WeeklyActivitiesCount < WeeklyCount
    self.table_name = "activities"

    def self.fetch(group_id)
      super(group_id, "start_time")
    end

    scope :monitored, lambda {
      where(is_reviewed: false)
        .where
        .not(
          actual_accomplishment_intensity: nil,
          actual_pleasure_intensity: nil
        )
        .where(
          predicted_accomplishment_intensity: nil,
          predicted_pleasure_intensity: nil
        )
    }

    scope :planned, lambda {
      where(
        is_reviewed: false,
        actual_accomplishment_intensity: nil,
        actual_pleasure_intensity: nil
      )
        .where
        .not(
          predicted_accomplishment_intensity: nil,
          predicted_pleasure_intensity: nil
        )
    }

    scope :reviewed_and_complete, lambda {
      where(is_reviewed: true)
        .where
        .not(
          predicted_accomplishment_intensity: nil,
          predicted_pleasure_intensity: nil,
          actual_accomplishment_intensity: nil,
          actual_pleasure_intensity: nil
        )
    }

    scope :reviewed_and_incomplete, lambda {
      where(is_reviewed: true)
        .where(
          actual_accomplishment_intensity: nil,
          actual_pleasure_intensity: nil
        )
        .where
        .not(
          predicted_accomplishment_intensity: nil,
          predicted_pleasure_intensity: nil
        )
    }
  end
end
