# frozen_string_literal: true
module GroupMetrics
  # Tabulate count of records (within a study week) for a Group.
  class WeeklyCount < ActiveRecord::Base
    self.abstract_class = true

    has_many :memberships,
             foreign_key: :participant_id,
             primary_key: :participant_id

    def self.fetch(group_id, timestamp_column = "created_at")
      pg_timezone = ActiveSupport::TimeZone[Time.zone.name].tzinfo.name

      joins(memberships: :participant)
        .select(<<-SQL
          ( FLOOR ( EXTRACT ( EPOCH FROM (
            ( #{connection.quote_table_name(table_name)}.#{connection.quote_table_name(timestamp_column)}
              AT TIME ZONE 'UTC' ) AT TIME ZONE #{connection.quote(pg_timezone)}
            - memberships.start_date ) ) / 604800 ) + 1
          )::int AS week, COUNT(1)
        SQL
               )
        .merge(Participant.not_moderator)
        .merge(Membership.where(group_id: group_id))
        .group(:week)
    end

    def week
      attributes["week"]
    end

    def count
      attributes["count"]
    end
  end
end
