# frozen_string_literal: true
module ThinkFeelDoEngine
  module Reports
    # Collect metadata for all Participant Emotional Ratings.
    class EmotionalRating
      def self.columns
        %w( participant_id name rating created_at is_positive )
      end

      def self.all
        Participant.not_moderator.select(:id, :study_id).map do |participant|
          participant.emotional_ratings.map do |emotional_rating|
            {
              participant_id: participant.study_id,
              name: emotional_rating.name,
              rating: emotional_rating.rating,
              created_at: emotional_rating.created_at.iso8601,
              is_positive: emotional_rating.is_positive
            }
          end
        end.flatten
      end
    end
  end
end
