# frozen_string_literal: true
module ThinkFeelDoEngine
  module Reports
    # Scenario: a Participant clicks, causes a page to render,
    # starts/pauses/finishes a video, etc.
    class Event
      def self.columns
        %w( participant_id is_admin emitted_at current_url headers kind )
      end

      def self.all
        Participant.not_moderator
                   .select(:id, :study_id, :is_admin).map do |participant|
          EventCapture::Event.where(participant_id: participant.id)
                             .map do |event|
            {
              participant_id: participant.study_id,
              is_admin: participant.is_admin,
              emitted_at: event.emitted_at.iso8601,
              current_url: event.current_url,
              headers: event.headers,
              kind: event.kind
            }
          end
        end.flatten
      end
    end
  end
end
