# frozen_string_literal: true
module ThinkFeelDoEngine
  module Reports
    # Collect metadata for each Participant Activity.
    class PatientActivity
      def self.columns
        %w( participant_id activity_title created_at start_time end_time
            actual_accomplishment_intensity actual_pleasure_intensity
            predicted_accomplishment_intensity predicted_pleasure_intensity
            noncompliance_reason is_reviewed )
      end

      def self.all
        Participant.not_moderator.select(:id, :study_id).map do |participant|
          participant.activities.map do |activity|
            {
              participant_id: participant.study_id,
              activity_title: activity.title,
              created_at: activity.created_at.iso8601,
              start_time: activity.start_time,
              end_time: activity.end_time,
              actual_accomplishment_intensity:
                activity.actual_accomplishment_intensity,
              actual_pleasure_intensity: activity.actual_pleasure_intensity,
              predicted_accomplishment_intensity:
                activity.predicted_accomplishment_intensity,
              predicted_pleasure_intensity:
                activity.predicted_pleasure_intensity,
              noncompliance_reason: activity.noncompliance_reason,
              is_reviewed: activity.is_reviewed
            }
          end
        end.flatten
      end
    end
  end
end
