# frozen_string_literal: true
module ThinkFeelDoEngine
  module Reports
    # Collect metadata for all Participant Thoughts.
    class PatientThought
      def self.columns
        %w( participant_id content effect created_at pattern challenging_thought
            act_as_if )
      end

      def self.all
        Participant.not_moderator
                   .select(:id, :study_id).map.map do |participant|
          participant.thoughts.map do |thought|
            {
              participant_id: participant.study_id,
              content: thought.content,
              effect: thought.effect,
              created_at: thought.created_at.iso8601,
              pattern: thought.pattern.try(:title),
              challenging_thought: thought.challenging_thought,
              act_as_if: thought.act_as_if
            }
          end
        end.flatten
      end
    end
  end
end
