# frozen_string_literal: true
module ThinkFeelDoEngine
  # Simplifies the logic of the media/audio access event views.
  class MediaAccessEventPresenter
    attr_reader :event, :start_date

    def initialize(event:, start_date:)
      @event = event
      @start_date = start_date
    end

    def completed
      end_time
    end

    def available_on(group)
      relased_on(group)
        .to_s(:user_date)
    end

    def duration_of_session
      end_time - created_at
    end

    def formatted_end_time
      end_time.to_s(:standard)
    end

    def formatted_start_time
      created_at.to_s(:standard)
    end

    def sortable(group)
      date = relased_on(group)
      Time.zone.local(date.year, date.month, date.day).to_i
    end

    def title
      event.slide_title
    end

    private

    def created_at
      event.created_at
    end

    def relased_on(group)
      start_date + (event.task_release_day(group) - 1)
    end

    def end_time
      event.end_time
    end
  end
end
