# frozen_string_literal: true
# Grouping logic for the visualization of participant mood and emotion data.
class MoodAndEmotionVisualizationService
  def initialize(participant)
    @participant = participant
  end

  def mood_rating_daily_averages
    averaged_ratings = []
    daily_ratings = @participant
                    .moods
                    .group_by { |x| x.created_at.strftime("%Y-%m-%d") }
    daily_ratings.each do |day, moods_array|
      ratings = moods_array.collect do |mood|
        [mood.rating, mood.created_at].compact
      end

      next if ratings.empty?

      averaged_ratings << { day: day,
                            intensity: average_rating(ratings),
                            is_positive: true,
                            drill_down: ratings,
                            data_type: "Mood" }
    end
    averaged_ratings
  end

  def emotional_rating_daily_averages
    averaged_ratings = []

    daily_ratings = @participant
                    .emotional_ratings
                    .group_by { |x| x.created_at.strftime("%Y-%m-%d") }
    daily_ratings.each do |day, emotion_array|
      positive_ratings = @participant.positive_emotions(emotion_array)
      unless positive_ratings.empty?
        daily_positive = { day: day,
                           intensity: average_rating(positive_ratings),
                           is_positive: true,
                           drill_down: positive_ratings,
                           data_type: "Emotion" }
        averaged_ratings << daily_positive
      end
      negative_ratings = @participant.negative_emotions(emotion_array)

      next if negative_ratings.empty?

      daily_negative = {  day: day,
                          intensity: average_rating(negative_ratings),
                          is_positive: false,
                          drill_down: negative_ratings, data_type: "Emotion" }
      averaged_ratings << daily_negative
    end
    averaged_ratings
  end

  private

  def average_rating(array)
    array.reduce(0) { |a, e| a.to_f + e[0] } / array.size
  end
end
